<!--排查单位查询-筛选弹层-->
<template>
  <van-popup
    v-model="isShowPopup"
    round
    closeable
    position="top"
    :style="{ height: '35%' }"
  >
    <div class="query-search-popup">
      <div class="title">条件查询</div>
      <van-form label-width="80px">
        <van-field
          name="caseType"
          label="排查方式"
          input-align="right"
          v-model="customQueryPrams.check_type_"
          placeholder="请选择排查方式"
          readonly
          clickable
          @click="checkTypePicker = true"
        />
        <van-field
          name="caseType"
          label="发布状态"
          input-align="right"
          v-model="customQueryPrams.pub_state_"
          placeholder="请选择发布状态"
          readonly
          clickable
          @click="pubStatePicker = true"
        />

        <div class="search-btn">
          <van-button class="btn-left" block type="info" native-type="button" @click="searchData">
            查询
          </van-button>
          <van-button class="btn-right" block plain type="info" native-type="button" @click="resetData">
            重置
          </van-button>
        </div>

        <!--  选择器  -->
        <template>
          <!--   排查方式   -->
          <van-popup v-model="checkTypePicker" position="bottom" get-container="body">
            <van-picker
              title="排查方式"
              show-toolbar
              value-key="name"
              :columns="checkTypeOpt"
              @cancel="_ => {
                customQueryPrams.check_type_ = ''
                checkTypePicker = false
              }"
              @confirm="
                ({name}) => {
                  customQueryPrams.check_type_ = name
                  checkTypePicker = false
                }
              "
            />
          </van-popup>

          <!--   发布状态   -->
          <van-popup v-model="pubStatePicker" position="bottom" get-container="body">
            <van-picker
              title="发布状态"
              show-toolbar
              value-key="name"
              :columns="pubStateOpt"
              @cancel="_ => {
                customQueryPrams.pub_state_ = ''
                pubStatePicker = false
              }"
              @confirm="
                ({name}) => {
                  customQueryPrams.pub_state_ = name
                  pubStatePicker = false
                }
              "
            />
          </van-popup>
        </template>
      </van-form>
    </div>
  </van-popup>
</template>

<script>
import moment from 'moment'

export default {
  name: 'QuerySearchPopup', // 排查单位查询-筛选弹层
  props: {
    // 是否展示弹层
    isShow: {
      default: false,
      type: Boolean
    },
    // 查询对象
    customQueryPrams: {
      default: () => ({
        check_type_: '',
        pub_state_: ''
      }),
      type: Object
    },
    checkTypeOpt: {
      default: () => ([]),
      type: Array
    },
    pubStateOpt: {
      default: () => ([]),
      type: Array
    }
  },
  data() {
    return {
      checkTypePicker: false, // 安全业务分类选择框显隐
      pubStatePicker: false // 发布状态选择框显隐
    }
  },
  computed: {
    isShowPopup: {
      get() {
        return this.isShow
      },
      set(val) {
        this.$emit('update:isShow', val)
      }
    }
  },
  methods: {
    moment,

    // 查询列表数据（校验成功后）
    searchData() {
      this.$emit('searchData', this.customQueryPrams)
      this.isShowPopup = false // 关闭筛选弹层
    },

    // 重置数据
    resetData() {
      /*
      * 重置数据，从父组件找到 “customQueryPrams对象” 的原始结构
      * 并还原表单原始状态
      * */
      Object.keys(this.customQueryPrams).forEach(key => {
        this.customQueryPrams[key] = this.$parent.$options.data().customQueryPrams[key]
      })
      this.$emit('searchData', this.customQueryPrams)
      this.isShowPopup = false // 关闭筛选弹层
    }
  }
}
</script>

<style lang="scss" scoped>
.query-search-popup {
  display: flex;
  flex-direction: column;
  height: 100%;

  .title {
    width: 100%;
    box-sizing: border-box;
    padding: 130px 0 100px 0;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 80px;
  }

  .van-form {
    flex: 1;
    position: relative;

    .search-btn {
      display: flex;
      position: absolute;
      bottom: 5%;
      width: 80%;
      transform: translateX(-50%);
      left: 50%;

      .van-button {

        &.btn-left {
          border-radius: 999px 0 0 999px;
        }

        &.btn-right {
          border-radius: 0 999px 999px 0;
        }

        .van-button__text {
          font-size: 65px;
        }
      }


    }
  }

  ::v-deep .year-picker {
    .van-picker__columns {
      .van-picker-column {

        &:nth-child(2) {
          display: none;
        }
      }
    }
  }
}
</style>

